searchData={"items":[{"type":"module","title":"Difflib.SequenceMatcher","doc":"SequenceMatcher is a flexible module for comparing pairs of sequences of\nany type, so long as the sequence elements are hashable.","ref":"Difflib.SequenceMatcher.html"},{"type":"module","title":"The algorithm - Difflib.SequenceMatcher","doc":"The basic algorithm predates, and is a little fancier than, an algorithm\npublished in the late 1980's by Ratcliff and Obershelp under the\nhyperbolic name \"gestalt pattern matching\".  The basic idea is to find\nthe longest contiguous matching subsequence that contains no \"junk\"\nelements (R-O doesn't address junk).\n\nThe same idea is then applied recursively to the pieces of the sequences to the left and to the right\nof the matching subsequence.  This does not yield minimal edit\nsequences, but does tend to yield matches that \"look right\" to people.\n\nSequenceMatcher tries to compute a \"human-friendly diff\" between two\nsequences.  Unlike e.g. UNIX(tm) diff, the fundamental notion is the\nlongest *contiguous* & junk-free matching subsequence.  That's what\ncatches peoples' eyes.\n\nThe Windows(tm) windiff has another interesting\nnotion, pairing up elements that appear uniquely in each sequence.\nThat, and the method here, appear to yield more intuitive difference\nreports than does diff.\n\nThis method appears to be the least vulnerable\nto synching up on blocks of \"junk lines\", though (like blank lines in\nordinary text files, or maybe \" \" lines in HTML files).  That may be\nbecause this is the only method of the 3 that has a *concept* of\n\"junk\"  .","ref":"Difflib.SequenceMatcher.html#module-the-algorithm"},{"type":"module","title":"Examples - Difflib.SequenceMatcher","doc":"Example, comparing two strings, and considering blanks to be \"junk\"\n\n    iex> is_junk = fn c -> c == \" \" end\n    iex> a = \"private Thread currentThread;\"\n    iex> b = \"private volatile Thread currentThread;\"\n    iex> SequenceMatcher.ratio(a, b, is_junk: is_junk)\n    0.8656716417910447\n\n`ratio/3` returns a float between 0 and 1, measuring the \"similarity\" of the\nsequences.  As a rule of thumb, a `ratio/3` value over 0.6 means the\nsequences are close matches.\n\nIf you're only interested in where the sequences match,\n`get_matching_blocks/3` is handy:\n\n    iex> for {a, b, size} <- SequenceMatcher.get_matching_blocks(a, b, is_junk: is_junk) do\n    iex>   IO.puts(\"a[#{a}] and b[#{b}] match for #{size} elements\")\n    iex> end\n    a[0] and b[0] match for 8 elements\n    a[8] and b[17] match for 21 elements\n    a[29] and b[38] match for 0 elements\n\nNote that the last tuple returned by `get_matching_blocks/3` is always a\ndummy, `{length(a), length(b), 0}`, and this is the only case in which the last\ntuple element (number of elements matched) is 0.\n\nIf you want to know how to change the first sequence into the second,\nuse `get_opcodes/3`\n\n    iex> for {op, a1, a2, b1, b2} <- SequenceMatcher.get_opcodes(a, b, is_junk: is_junk) do\n    iex>   IO.puts(\"#{op} a[#{a1}:#{a2}] b[#{b1}:#{b2}]\")\n    iex> end\n    equal a[0:8] b[0:8]\n    insert a[8:8] b[8:17]\n    equal a[8:29] b[17:38]\n\nSee also function `get_close_matches/3` in this module, which shows how\nsimple code building on SequenceMatcher can be used to do useful work.\n\nTiming:  Basic R-O is cubic time worst case and quadratic time expected\ncase.  SequenceMatcher is quadratic time for the worst case and has\nexpected-case behavior dependent in a complicated way on how many\nelements the sequences have in common; best case time is linear.","ref":"Difflib.SequenceMatcher.html#module-examples"},{"type":"function","title":"Difflib.SequenceMatcher.chain_b/2","doc":"Analyzes an input for junk elements.","ref":"Difflib.SequenceMatcher.html#chain_b/2"},{"type":"function","title":"Background - Difflib.SequenceMatcher.chain_b/2","doc":"Because `is_junk` is a user-defined function, and we test\nfor junk a LOT, it's important to minimize the number of calls.\nBefore the tricks described here, `chain_b/2` was by far the most\ntime-consuming routine in the whole module!  If anyone sees\nJim Roskind, thank him again for [profile.py](https://github.com/python/cpython/blob/main/Lib/profile.py) -- I never would\nhave guessed that.\n\nThe first trick is to build `b2j` ignoring the possibility\nof junk.  I.e., we don't call is_junk at all yet.  Throwing\nout the junk later is much cheaper than building `b2j` \"right\"\nfrom the start.","ref":"Difflib.SequenceMatcher.html#chain_b/2-background"},{"type":"function","title":"Parameters - Difflib.SequenceMatcher.chain_b/2","doc":"- `a` - The first of two sequences to be compared. The elements of a must be hashable.\n  - `b` - The second of two sequences to be compared. The elements of b must be hashable.\n  - `opts` - Keyword list of options.\n    - `is_junk` - Optional parameter is_junk is a one-argument\n  function that takes a sequence element and returns true if the\n  element is junk. The default is `nil`. For example, pass\n      `fn x -> x == \" \"`\n  if you're comparing lines as sequences of characters, and don't\n  want to synch up on blanks or hard tabs.\n    - `auto_junk` - Optional parameter autojunk should be set to false to disable the\n  \"automatic junk heuristic\" that treats popular elements as junk. The default is `true`.","ref":"Difflib.SequenceMatcher.html#chain_b/2-parameters"},{"type":"function","title":"Example - Difflib.SequenceMatcher.chain_b/2","doc":"iex> is_junk = fn x -> x == \" \" end\n    iex> b = \"abcd abcd\"\n    iex> SequenceMatcher.chain_b(b, is_junk: is_junk)\n    %{\n      b2j: %{\n        \"a\" => [0, 5],\n        \"b\" => [1, 6],\n        \"c\" => [2, 7],\n        \"d\" => [3, 8]\n      },\n      isbjunk: #Function<1.118419402/1>,\n      isbpopular: #Function<1.118419402/1>,\n      bjunk: %{\" \" => true},\n      bpopular: %{}\n    }","ref":"Difflib.SequenceMatcher.html#chain_b/2-example"},{"type":"function","title":"Difflib.SequenceMatcher.find_longest_match/3","doc":"Find longest matching block in a[alo...ahi] and b[blo...bhi].","ref":"Difflib.SequenceMatcher.html#find_longest_match/3"},{"type":"function","title":"Description - Difflib.SequenceMatcher.find_longest_match/3","doc":"If `is_junk` is not defined:\n\nReturn `{i,j,k}` such that `a[i...i+k]` is equal to `b[j...j+k]`, where\n    alo <= i <= i+k <= ahi\n    blo <= j <= j+k <= bhi\nand for all `{i',j',k'}` meeting those conditions,\n    k >= k'\n    i <= i'\n    and if i == i', j <= j'\n\nIn other words, of all maximal matching blocks, return one that\nstarts earliest in a, and of all those maximal matching blocks that\nstart earliest in a, return the one that starts earliest in b.","ref":"Difflib.SequenceMatcher.html#find_longest_match/3-description"},{"type":"function","title":"Parameters - Difflib.SequenceMatcher.find_longest_match/3","doc":"- `a` - The first of two sequences to be compared. The elements of a must be hashable.\n  - `b` - The second of two sequences to be compared. The elements of b must be hashable.\n  - `opts` - Keyword list of options.\n    - `alo` - Optional parameter alo is the lower bound of the range in a to consider. The default is 0.\n    - `ahi` - Optional parameter ahi is the upper bound of the range in a to consider. The default is length of a.\n    - `blo` - Optional parameter blo is the lower bound of the range in b to consider. The default is 0.\n    - `bhi` - Optional parameter bhi is the upper bound of the range in b to consider. The default is length of b.\n    - `is_junk` - Optional parameter is_junk is a one-argument\n  function that takes a sequence element and returns true if the\n  element is junk. The default is `nil`. For example, pass\n      `fn x -> x == \" \"`\n  if you're comparing lines as sequences of characters, and don't\n  want to synch up on blanks or hard tabs.\n    - `auto_junk` - Optional parameter autojunk should be set to false to disable the\n  \"automatic junk heuristic\" that treats popular elements as junk. The default is `true`.","ref":"Difflib.SequenceMatcher.html#find_longest_match/3-parameters"},{"type":"function","title":"Examples - Difflib.SequenceMatcher.find_longest_match/3","doc":"iex> is_junk = fn x -> x == \" \" end\n    iex> a = \" abcd\"\n    iex> b = \"abcd abcd\"\n    iex> SequenceMatcher.find_longest_match(a, b, alo: 0, ahi: 5, blo: 0, bhi: 9, is_junk: is_junk)\n    {1, 0, 4}\n\n    iex> a = \"ab\"\n    iex> b = \"c\"\n    iex> SequenceMatcher.find_longest_match(a, b, alo: 0, ahi: 2, blo: 0, bhi: 1)\n    {0, 0, 0}","ref":"Difflib.SequenceMatcher.html#find_longest_match/3-examples"},{"type":"function","title":"CAUTION - Difflib.SequenceMatcher.find_longest_match/3","doc":"CAUTION:  stripping common prefix or suffix would be incorrect.\nE.g.,\n    ab\n    acab\nLongest matching block is \"ab\", but if common prefix is\nstripped, it's \"a\" (tied with \"b\").  UNIX(tm) diff does so\nstrip, so ends up claiming that ab is changed to acab by\ninserting \"ca\" in the middle.  That's minimal but unintuitive:\n\"it's obvious\" that someone inserted \"ac\" at the front.\nWindiff ends up at the same place as diff, but by pairing up\nthe unique 'b's and then matching the first two 'a's.","ref":"Difflib.SequenceMatcher.html#find_longest_match/3-caution"},{"type":"function","title":"Difflib.SequenceMatcher.get_close_matches/3","doc":"Use SequenceMatcher to return list of the best \"good enough\" matches.","ref":"Difflib.SequenceMatcher.html#get_close_matches/3"},{"type":"function","title":"Description - Difflib.SequenceMatcher.get_close_matches/3","doc":"The best (no more than `n`) matches among the possibilities are returned\nin a list, sorted by similarity score, most similar first.","ref":"Difflib.SequenceMatcher.html#get_close_matches/3-description"},{"type":"function","title":"Parameters - Difflib.SequenceMatcher.get_close_matches/3","doc":"- `word` - The sequence for which close matches are desired. Typically a string.\n- `possibilities` - A list of sequences against which to match word. Typically a list of strings.\n- `opts` - Keyword list of options.\n  - `n` - Optional parameter n is the maximum number of close matches to return. The default is 3 and n must be > 0.\n  - `cutoff` - Optional parameter cutoff is a float between 0 and 1. Possibilities that don't score at least that similar to word are ignored. The default is 0.6.\n  - `is_junk` - Optional parameter is_junk is a one-argument\n  function that takes a sequence element and returns true if the\n  element is junk. The default is `nil`. For example, pass `fn x -> x == \" \"` if you're comparing lines as sequences of characters, and don't want to synch up on blanks or hard tabs.\n    - `auto_junk` - Optional parameter autojunk should be set to false to disable the\n  \"automatic junk heuristic\" that treats popular elements as junk. The default is `true`.","ref":"Difflib.SequenceMatcher.html#get_close_matches/3-parameters"},{"type":"function","title":"Example - Difflib.SequenceMatcher.get_close_matches/3","doc":"iex> SequenceMatcher.get_close_matches(\"appel\", [\"ape\", \"apple\", \"peach\", \"puppy\"])\n    [\"apple\", \"ape\"]","ref":"Difflib.SequenceMatcher.html#get_close_matches/3-example"},{"type":"function","title":"Difflib.SequenceMatcher.get_grouped_opcodes/3","doc":"Isolate change clusters by eliminating ranges with no changes.","ref":"Difflib.SequenceMatcher.html#get_grouped_opcodes/3"},{"type":"function","title":"Description - Difflib.SequenceMatcher.get_grouped_opcodes/3","doc":"Return a list groups with up to `n` lines of context.\nEach group is in the same format as returned by `get_opcodes/3`.","ref":"Difflib.SequenceMatcher.html#get_grouped_opcodes/3-description"},{"type":"function","title":"Parameters - Difflib.SequenceMatcher.get_grouped_opcodes/3","doc":"- `a` - The first of two sequences to be compared. The elements of a must be hashable.\n- `b` - The second of two sequences to be compared. The elements of b must be hashable.\n- `opts` - Keyword list of options.\n  - `n` - Optional parameter n is the number of lines of context to include in each group. The default is 3.\n  - `is_junk` - Optional parameter is_junk is a one-argument\nfunction that takes a sequence element and returns true if the\nelement is junk. The default is `nil`. For example, pass\n    `fn x -> x == \" \"`\nif you're comparing lines as sequences of characters, and don't\nwant to synch up on blanks or hard tabs.\n  - `auto_junk` - Optional parameter autojunk should be set to false to disable the\n\"automatic junk heuristic\" that treats popular elements as junk. The default is `true`.","ref":"Difflib.SequenceMatcher.html#get_grouped_opcodes/3-parameters"},{"type":"function","title":"Example - Difflib.SequenceMatcher.get_grouped_opcodes/3","doc":"iex> a = Enum.map(1..39, &Integer.to_string/1)\n    iex> b = Enum.slice(a, 0..-1)\n    iex> b = Enum.slice(b, 0..7) ++ [\"i\"] ++ Enum.slice(b, 8..-1)\n    iex> b = Enum.slice(b, 0..19) ++ [\"20x\"] ++ Enum.slice(b, 21..-1)\n    iex> b = Enum.slice(b, 0..22) ++ Enum.slice(b, 28..-1)\n    iex> b = Enum.slice(b, 0..29) ++ [\"35y\"] ++ Enum.slice(b, 31..-1)\n    iex> SequenceMatcher.get_grouped_opcodes(a, b)\n    [\n      [\n        {:equal, 5, 8, 5, 8},\n        {:insert, 8, 8, 8, 9},\n        {:equal, 8, 11, 9, 12}],\n      [\n        {:equal, 16, 19, 17, 20},\n        {:replace, 19, 20, 20, 21},\n        {:equal, 20, 22, 21, 23},\n        {:delete, 22, 27, 23, 23},\n        {:equal, 27, 30, 23, 26}\n      ],\n      [\n        {:equal, 31, 34, 27, 30},\n        {:replace, 34, 35, 30, 31},\n        {:equal, 35, 38, 31, 34}\n      ]\n    ]","ref":"Difflib.SequenceMatcher.html#get_grouped_opcodes/3-example"},{"type":"function","title":"Difflib.SequenceMatcher.get_matching_blocks/3","doc":"Return list of triples describing matching subsequences.","ref":"Difflib.SequenceMatcher.html#get_matching_blocks/3"},{"type":"function","title":"Description - Difflib.SequenceMatcher.get_matching_blocks/3","doc":"Each triple is of the form `{i, j, n}`, and means that\n`a[i...i+n] == b[j...j+n]`.  The triples are monotonically increasing in\n`i` and in `j`.  it's also guaranteed that if\n`{i, j, n}` and `{i', j', n'}` are adjacent triples in the list, and\nthe second is not the last triple in the list, then `i+n != i'` or\n`j+n != j'`.  IOW, adjacent triples never describe adjacent equal\nblocks.\n\nThe last triple is a dummy, `{a.length, b.length, 0}`, and is the only\ntriple with `n==0`.","ref":"Difflib.SequenceMatcher.html#get_matching_blocks/3-description"},{"type":"function","title":"Parameters - Difflib.SequenceMatcher.get_matching_blocks/3","doc":"- `a` - The first of two sequences to be compared. The elements of a must be hashable.\n- `b` - The second of two sequences to be compared. The elements of b must be hashable.\n- `opts` - Keyword list of options.\n  - `is_junk` - Optional parameter is_junk is a one-argument\nfunction that takes a sequence element and returns true if the\nelement is junk. The default is `nil`. For example, pass\n    `fn x -> x == \" \"`\nif you're comparing lines as sequences of characters, and don't\nwant to synch up on blanks or hard tabs.\n  - `auto_junk` - Optional parameter autojunk should be set to false to disable the\n\"automatic junk heuristic\" that treats popular elements as junk. The default is `true`.","ref":"Difflib.SequenceMatcher.html#get_matching_blocks/3-parameters"},{"type":"function","title":"Example - Difflib.SequenceMatcher.get_matching_blocks/3","doc":"iex> a = \"abxcd\"\n    iex> b = \"abcd\"\n    iex> SequenceMatcher.get_matching_blocks(a, b)\n    [{0, 0, 2}, {3, 2, 2}, {5, 4, 0}]","ref":"Difflib.SequenceMatcher.html#get_matching_blocks/3-example"},{"type":"function","title":"Difflib.SequenceMatcher.get_opcodes/3","doc":"Return list of 5-tuples describing how to turn a into b.","ref":"Difflib.SequenceMatcher.html#get_opcodes/3"},{"type":"function","title":"Description - Difflib.SequenceMatcher.get_opcodes/3","doc":"Each tuple is of the form `{tag, i1, i2, j1, j2}`.  The first tuple\nhas `i1 == j1 == 0`, and remaining tuples have `i1 ==` the `i2` from the\ntuple preceding it, and likewise for `j1 ==` the previous `j2`.\n\nThe tags are atoms, with these meanings:\n\n- `:replace` - `a[i1...i2]` should be replaced by `b[j1...j2]`\n- `:delete` - `a[i1...i2]` should be deleted. Note that `j1==j2` in this case.\n- `:insert` - `b[j1...j2]` should be inserted at `a[i1...i1]`. Note that `i1==i2` in this case.\n- `:equal` - `a[i1...i2] == b[j1...j2]`","ref":"Difflib.SequenceMatcher.html#get_opcodes/3-description"},{"type":"function","title":"Parameters - Difflib.SequenceMatcher.get_opcodes/3","doc":"- `a` - The first of two sequences to be compared. The elements of a must be hashable.\n- `b` - The second of two sequences to be compared. The elements of b must be hashable.\n- `opts` - Keyword list of options.\n  - `is_junk` - Optional parameter is_junk is a one-argument\nfunction that takes a sequence element and returns true if the\nelement is junk. The default is `nil`. For example, pass\n    `fn x -> x == \" \"`\nif you're comparing lines as sequences of characters, and don't\nwant to synch up on blanks or hard tabs.\n  - `auto_junk` - Optional parameter autojunk should be set to false to disable the\n\"automatic junk heuristic\" that treats popular elements as junk. The default is `true`.","ref":"Difflib.SequenceMatcher.html#get_opcodes/3-parameters"},{"type":"function","title":"Example - Difflib.SequenceMatcher.get_opcodes/3","doc":"iex> a = \"qabxcd\"\n    iex> b = \"abycdf\"\n    iex> SequenceMatcher.get_opcodes(a, b)\n    [\n      {:delete, 0, 1, 0, 0},\n      {:equal, 1, 3, 0, 2},\n      {:replace, 3, 4, 2, 3},\n      {:equal, 4, 6, 3, 5},\n      {:insert, 6, 6, 5, 6}\n    ]","ref":"Difflib.SequenceMatcher.html#get_opcodes/3-example"},{"type":"function","title":"Difflib.SequenceMatcher.quick_ratio/3","doc":"Return an upper bound on `ratio/3` relatively quickly.","ref":"Difflib.SequenceMatcher.html#quick_ratio/3"},{"type":"function","title":"Description - Difflib.SequenceMatcher.quick_ratio/3","doc":"This isn't defined beyond that it is an upper bound on `ratio/3`, and is faster to compute.","ref":"Difflib.SequenceMatcher.html#quick_ratio/3-description"},{"type":"function","title":"Parameters - Difflib.SequenceMatcher.quick_ratio/3","doc":"- `a` - The first of two sequences to be compared. The elements of a must be hashable.\n- `b` - The second of two sequences to be compared. The elements of b must be hashable.\n- `opts` - Keyword list of options.\n  - `fullbcount` - Optional parameter fullbcount is a map of the counts of each element in b.\nIt will be constructed if it does not exist. The default is `nil`.","ref":"Difflib.SequenceMatcher.html#quick_ratio/3-parameters"},{"type":"function","title":"Example - Difflib.SequenceMatcher.quick_ratio/3","doc":"iex> a = \"abcd\"\n    iex> b = \"bcde\"\n    iex> SequenceMatcher.quick_ratio(a, b)\n    0.75","ref":"Difflib.SequenceMatcher.html#quick_ratio/3-example"},{"type":"function","title":"Difflib.SequenceMatcher.ratio/3","doc":"Return a measure of the sequences' similarity (float between 0 and 1).","ref":"Difflib.SequenceMatcher.html#ratio/3"},{"type":"function","title":"Description - Difflib.SequenceMatcher.ratio/3","doc":"Where `T` is the total number of elements in both sequences, and\n`M` is the number of matches, this is `2.0*M / T`.\nNote that this is 1 if the sequences are identical, and 0 if\nthey have nothing in common.\n\n`ratio/3` is expensive to compute if you haven't already computed\n`get_matching_blocks/3` or `get_opcodes/3`, in which case you may\nwant to try `quick_ratio/3` or `real_quick_ratio/3` first to get an\nupper bound.","ref":"Difflib.SequenceMatcher.html#ratio/3-description"},{"type":"function","title":"Parameters - Difflib.SequenceMatcher.ratio/3","doc":"- `a` - The first of two sequences to be compared. The elements of a must be hashable.\n- `b` - The second of two sequences to be compared. The elements of b must be hashable.\n- `opts` - Keyword list of options.\n  - `is_junk` - Optional parameter is_junk is a one-argument\nfunction that takes a sequence element and returns true if the\nelement is junk. The default is `nil`. For example, pass\n    `fn x -> x == \" \"`\nif you're comparing lines as sequences of characters, and don't\nwant to synch up on blanks or hard tabs.\n  - `auto_junk` - Optional parameter autojunk should be set to false to disable the\n\"automatic junk heuristic\" that treats popular elements as junk. The default is `true`.","ref":"Difflib.SequenceMatcher.html#ratio/3-parameters"},{"type":"function","title":"Example - Difflib.SequenceMatcher.ratio/3","doc":"iex> a = \"abcd\"\n    iex> b = \"bcde\"\n    iex> SequenceMatcher.ratio(a, b)\n    0.75","ref":"Difflib.SequenceMatcher.html#ratio/3-example"},{"type":"function","title":"Difflib.SequenceMatcher.real_quick_ratio/2","doc":"Return an upper bound on `ratio/3` very quickly.","ref":"Difflib.SequenceMatcher.html#real_quick_ratio/2"},{"type":"function","title":"Description - Difflib.SequenceMatcher.real_quick_ratio/2","doc":"This isn't defined beyond that it is an upper bound on `ratio/3`, and\nis faster to compute than either `ratio/3` or `quick_ratio/3`.","ref":"Difflib.SequenceMatcher.html#real_quick_ratio/2-description"},{"type":"function","title":"Parameters - Difflib.SequenceMatcher.real_quick_ratio/2","doc":"- `a` - The first of two sequences to be compared. The elements of a must be hashable.\n- `b` - The second of two sequences to be compared. The elements of b must be hashable.","ref":"Difflib.SequenceMatcher.html#real_quick_ratio/2-parameters"},{"type":"function","title":"Example - Difflib.SequenceMatcher.real_quick_ratio/2","doc":"iex> a = \"abcd\"\n    iex> b = \"bcde\"\n    iex> SequenceMatcher.real_quick_ratio(a, b)\n    1.0","ref":"Difflib.SequenceMatcher.html#real_quick_ratio/2-example"},{"type":"extras","title":"Difflib","doc":"# Difflib\n\nA set of helpers for computing deltas between objects.\n\nDifflib is a partial port of python 3's [difflib](https://github.com/python/cpython/blob/main/Lib/difflib.py).\n\nThe port is meant to closely resemble the code, docs, and tests from the python implementation for easy reference between the two.","ref":"readme.html"},{"type":"extras","title":"Status of the classes and functions to be ported from python - Difflib","doc":"Completed:\n- Class `SequenceMatcher`: A flexible class for comparing pairs of sequences of any type.\n  - implemented as the module `Difflib.SequenceMatcher`\n- Function `get_close_matches(word, possibilities, n=3, cutoff=0.6)`: Use SequenceMatcher to return list of the best \"good enough\" matches.\n  - implemented in the `Difflib.SequenceMatcher` module\n\nNot Started: \n- Function `context_diff(a, b)`: For two lists of strings, return a delta in context diff format.\n- Function `ndiff(a, b)`: Return a delta: the difference between `a` and `b` (lists of strings).\n- Function `restore(delta, which)`: Return one of the two sequences that generated an ndiff delta.\n- Function `unified_diff(a, b)`: For two lists of strings, return a delta in unified diff format.\n- Class `Differ`: For producing human-readable deltas from sequences of lines of text.\n- Class `HtmlDiff`: For producing HTML side by side comparison with change highlights.","ref":"readme.html#status-of-the-classes-and-functions-to-be-ported-from-python"},{"type":"extras","title":"Installation - Difflib","doc":"The package can be installed by adding `difflib` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:difflib, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic Usage - Difflib","doc":"``` elixir\niex> SequenceMatcher.get_close_matches(\"appel\", [\"ape\", \"apple\", \"peach\", \"puppy\"])\n[\"apple\", \"ape\"]\n\niex> a = \"qabxcd\"\niex> b = \"abycdf\"\niex> SequenceMatcher.get_opcodes(a, b)\n[\n  {:delete, 0, 1, 0, 0},\n  {:equal, 1, 3, 0, 2},\n  {:replace, 3, 4, 2, 3},\n  {:equal, 4, 6, 3, 5},\n  {:insert, 6, 6, 5, 6}\n]\n\niex> a = \"abcd\"\niex> b = \"bcde\"\niex> SequenceMatcher.ratio(a, b)\n0.75\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"Documentation - Difflib","doc":"Complete documentation can be found at [https://hexdocs.pm/difflib](https://hexdocs.pm/difflib)","ref":"readme.html#documentation"},{"type":"extras","title":"Source - Difflib","doc":"Code can be found at [https://github.com/gschro/difflib](https://github.com/gschro/difflib)","ref":"readme.html#source"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 Garrett Schroath\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}